/**************************************************************************//**
 * @file     main.c
 * @version  V4.0
 * $Date: 19/01/16 06:00p $
 * @brief    To utilize emWin library to demonstrate interactive feature.
 *
 * @note
 * Copyright (C) 2019 Nuvoton Technology Corp. All rights reserved.
 ******************************************************************************/
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include  <stdarg.h>
#include  <math.h>
#include "N9H30.h"
#include "sys.h"

#ifdef __USE_SD__
#include "sdh.h"
#else
#include "spi.h"
#include "spilib.h"
#endif

#include "gpio.h"
#include "lcd.h"

#include "TouchPanel.h"
#include "gui.h"
#include "wm.h"
#include "FRAMEWIN.h"
#include "LCD_Protected.h"
#include "LCDconf.h"
#if GUI_WINSUPPORT
#include "wm.h"
#include "text.h"
#endif

#ifdef __USE_SD__
#include "diskio.h"
#include "ff.h"
#endif

#include "RTC.h"
uint8_t *g_VAFrameBuf;

#include "FreeRTOS.h"
#include "task.h"
#include "semphr.h"
#include "MainTask.h"
extern void ALARM_BackgroundProcess (void);
//volatile int ts_flag;
extern void TouchTask(void);

BOOL g_isInited;
unsigned int g_10msTick;
unsigned int g_sx10Tick;



extern RTC_TIME_DATA_T g_sCurTime;


#ifdef __USE_SD__
FATFS FatFs[_VOLUMES];      /* File system object for logical drive */

__align(32) BYTE Buff[1024] ;       /* Working buffer */

FIL hFile;
#else
uint32_t * g_pu32Res;
uint8_t DestArray[1024];
#endif

extern int ts_writefile(void);
extern int ts_readfile(void);
extern int ts_calibrate(int xsize, int ysize);
extern int ts_phy2log(int *sumx, int *sumy);
extern int ts_test(int xsize, int ysize);

static void vTaskGUI(void *pvParameters);
static void vTaskTaskUserIF(void *pvParameters);
static void vTaskLED(void *pvParameters);
static void vTaskMsgPro(void *pvParameters);

static void AppTaskCreate (void);
static void AppObjCreate (void);
static void AppTaskStart(void *pvParameters);

static TaskHandle_t xHandleTaskUserIF = NULL;
static TaskHandle_t xHandleTaskLED = NULL;
static TaskHandle_t xHandleTaskMsgPro = NULL;
static TaskHandle_t xHandleTaskStart = NULL;
static SemaphoreHandle_t  xMutex = NULL;

BOOL volatile alarm_now = 1;

uint8_t *g_VAFrameBuf;


//#ifdef __USE_SD__
/*---------------------------------------------------------*/
/* User Provided RTC Function for FatFs module             */
/*---------------------------------------------------------*/
/* This is a real time clock service to be called from     */
/* FatFs module. Any valid time must be returned even if   */
/* the system does not support an RTC.                     */
/* This function is not required in read-only cfg.         */

unsigned long get_fattime (void)
{
    unsigned long tmr;

    tmr=0x00000;

    return tmr;
}
//#endif

void LCD_initial(void)
{
    // Configure multi-function pin for LCD interface
    //GPG6 (CLK), GPG7 (HSYNC)
    outpw(REG_SYS_GPG_MFPL, (inpw(REG_SYS_GPG_MFPL)& ~0xFF000000) | 0x22000000);
    //GPG8 (VSYNC), GPG9 (DEN)
    outpw(REG_SYS_GPG_MFPH, (inpw(REG_SYS_GPG_MFPH)& ~0xFF) | 0x22);

    //DATA pin
    //GPA0 ~ GPA7 (DATA0~7)
    outpw(REG_SYS_GPA_MFPL, 0x22222222);
    //GPA8 ~ GPA15 (DATA8~15)
    outpw(REG_SYS_GPA_MFPH, 0x22222222);
#ifdef _PANEL_FW070TFT_24BPP_
    //GPD8 ~ GPD15 (DATA16~23)
    outpw(REG_SYS_GPD_MFPH, 0x22222222);
#endif

#ifdef _PANEL_E50A2V1_16BPP_
    // LCD clock is selected from UPLL and divide to 20MHz
    outpw(REG_CLK_DIVCTL1, (inpw(REG_CLK_DIVCTL1) & ~0xff1f) | 0xe18);
#endif
#ifdef _PANEL_FW070TFT_24BPP_
    // LCD clock is selected from UPLL and divide to 30MHz
    outpw(REG_CLK_DIVCTL1, (inpw(REG_CLK_DIVCTL1) & ~0xff1f) | 0x918);
#endif

#ifdef _PANEL_E50A2V1_16BPP_
    // Init LCD interface for E50A2V1 LCD module
    vpostLCMInit(DIS_PANEL_E50A2V1);
#endif
#ifdef _PANEL_FW070TFT_24BPP_
    // Init LCD interface for FW070TFT LCD module
    vpostLCMInit(DIS_PANEL_FW070TFT);
#endif
    // Set scale to 1:1
    vpostVAScalingCtrl(1, 0, 1, 0, VA_SCALE_INTERPOLATION);

    // Set display color depth
#ifdef _PANEL_E50A2V1_16BPP_
    vpostSetVASrc(VA_SRC_RGB565);
#endif
#ifdef _PANEL_FW070TFT_24BPP_
    vpostSetVASrc(VA_SRC_RGB888);
#endif

    // Get pointer of video frame buffer
    // Note: before get pointer of frame buffer, must set display color depth first
    g_VAFrameBuf = vpostGetFrameBuffer();
    if(g_VAFrameBuf == NULL)
    {
        sysprintf("Get buffer error !!\n");
        while(1);
    }

#ifdef _PANEL_E50A2V1_16BPP_
    memset((void *)g_VAFrameBuf, 0, LCD_XSIZE*LCD_YSIZE*2);
#endif
#ifdef _PANEL_FW070TFT_24BPP_
    memset((void *)g_VAFrameBuf, 0, LCD_XSIZE*LCD_YSIZE*4);
#endif

    // Start video
    //vpostVAStartTrigger();
}

extern volatile int OS_TimeMS;
volatile int g_enable_Touch;

void TMR0_IRQHandler(void)
{
    OS_TimeMS++;
}

void TMR0_IRQHandler_TouchTask(void)
{
    //sysprintf("g_enable_Touch=%d\n", g_enable_Touch);
    if ( g_enable_Touch == 1 )
    {
        //sysprintf("enable_Touch=%d\n", g_enable_Touch);
        TouchTask();
    }
}

#ifdef __USE_SD__
BYTE SD_Drv; // select SD0
unsigned int volatile gCardInit = 0;
void SDH_IRQHandler(void)
{
    unsigned int volatile isr;

    // FMI data abort interrupt
    if (inpw(REG_SDH_GINTSTS) & SDH_GINTSTS_DTAIF_Msk)
    {
        /* ResetAllEngine() */
        outpw(REG_SDH_GCTL, inpw(REG_SDH_GCTL) | SDH_GCTL_GCTLRST_Msk);
        outpw(REG_SDH_GINTSTS, SDH_GINTSTS_DTAIF_Msk);
    }

    //----- SD interrupt status
    isr = inpw(REG_SDH_INTSTS);
    if (isr & SDH_INTSTS_BLKDIF_Msk)        // block down
    {
        _sd_SDDataReady = TRUE;
        outpw(REG_SDH_INTSTS, SDH_INTSTS_BLKDIF_Msk);
    }

    if (isr & SDH_INTSTS_CDIF0_Msk)   // port 0 card detect
    {
        //----- SD interrupt status
        // it is work to delay 50 times for SD_CLK = 200KHz
        {
            volatile int i;         // delay 30 fail, 50 OK
            for (i=0; i<0x500; i++);   // delay to make sure got updated value from REG_SDISR.
            isr = inpw(REG_SDH_INTSTS);
        }

#ifdef _USE_DAT3_DETECT_
        if (!(isr & SDH_INTSTS_CDSTS0_Msk))
        {
            SD0.IsCardInsert = FALSE;
            sysprintf("\nCard Remove!\n");
            SD_Close_Disk(0);
        }
        else
        {
            SD_Open_Disk(SD_PORT0 | CardDetect_From_DAT3);
        }
#else
        if (isr & SDH_INTSTS_CDSTS0_Msk)
        {
            SD0.IsCardInsert = FALSE;   // SDISR_CD_Card = 1 means card remove for GPIO mode
            gCardInit = 0;
            sysprintf("\nCard Remove!\n");
            SD_Close_Disk(0);
        }
        else
        {
            gCardInit = 1;
            //SD_Open_Disk(SD_PORT0 | CardDetect_From_GPIO);
        }
#endif

        outpw(REG_SDH_INTSTS, SDH_INTSTS_CDIF0_Msk);
    }

    if (isr & SDH_INTSTS_CDIF1_Msk)   // port 1 card detect
    {
        //----- SD interrupt status
        // it is work to delay 50 times for SD_CLK = 200KHz
        {
            volatile int i;         // delay 30 fail, 50 OK
            for (i=0; i<0x500; i++);   // delay to make sure got updated value from REG_SDISR.
            isr = inpw(REG_SDH_INTSTS);
        }

#ifdef _USE_DAT3_DETECT_
        if (!(isr & SDH_INTSTS_CDSTS1_Msk))
        {
            SD0.IsCardInsert = FALSE;
            sysprintf("\nCard Remove!\n");
            SD_Close_Disk(1);
        }
        else
        {
            SD_Open_Disk(SD_PORT1 | CardDetect_From_DAT3);
        }
#else
        if (isr & SDH_INTSTS_CDSTS1_Msk)
        {
            SD0.IsCardInsert = FALSE;   // SDISR_CD_Card = 1 means card remove for GPIO mode
            sysprintf("\nCard Remove!\n");
            SD_Close_Disk(1);
        }
        else
        {
            SD_Open_Disk(SD_PORT1 | CardDetect_From_GPIO);
        }
#endif

        outpw(REG_SDH_INTSTS, SDH_INTSTS_CDIF1_Msk);
    }

    // CRC error interrupt
    if (isr & SDH_INTSTS_CRCIF_Msk)
    {
        if (!(isr & SDH_INTSTS_CRC16_Msk))
        {
            //sysprintf("***** ISR sdioIntHandler(): CRC_16 error !\n");
            // handle CRC error
        }
        else if (!(isr & SDH_INTSTS_CRC7_Msk))
        {
            extern unsigned int _sd_uR3_CMD;
            if (! _sd_uR3_CMD)
            {
                //sysprintf("***** ISR sdioIntHandler(): CRC_7 error !\n");
                // handle CRC error
            }
        }
        outpw(REG_SDH_INTSTS, SDH_INTSTS_CRCIF_Msk);      // clear interrupt flag
    }
}
#endif

void SYS_Init(void)
{
#ifdef __USE_SD__
    /* enable SDH */
    outpw(REG_CLK_HCLKEN, inpw(REG_CLK_HCLKEN) | 0x40000000);

    /* select multi-function-pin */
    /* SD Port 0 -> PD0~7 */
    outpw(REG_SYS_GPD_MFPL, 0x66666666);
    SD_Drv = 0;
#endif

#if 0 // port 1
    /* initial SD1 pin -> PI5~10, 12~13 */
    outpw(REG_SYS_GPI_MFPL, inpw(REG_SYS_GPI_MFPL) & ~0xfff00000 | 0x44400000);
    outpw(REG_SYS_GPI_MFPH, inpw(REG_SYS_GPI_MFPH) & ~0x00ff0fff | 0x00440444);
    SD_Drv = 1;
#endif

}

VOID RTC_TickISR(void)
{
    RTC_TIME_DATA_T sCurTime;

    /* Get the currnet time */
    RTC_Read(RTC_CURRENT_TIME, &sCurTime);

//    sysprintf("   Current Time:%d/%02d/%02d %02d:%02d:%02d\n",sCurTime.u32Year,sCurTime.u32cMonth,sCurTime.u32cDay,sCurTime.u32cHour,sCurTime.u32cMinute,sCurTime.u32cSecond);
    RTC_EnableClock(TRUE);
  //  g_u32TICK++;

}

VOID RTC_AlarmISR(void)
{

    sysprintf("    Alarm!!\n");

    alarm_now = 0 ;//g_bAlarm = TRUE;
}

extern RTC_TIME_DATA_T g_sAlarmTime;
void RTC_Alarm_init(void)
{
	RTC_TIME_DATA_T sInitTime, sAlarmTime;
	RTC_TICK_T sTick;

	RTC_EnableClock(TRUE);

	/* RTC Initialize */
	RTC_Init();

	/* Time Setting */
	sInitTime.u32Year = 2018;
	sInitTime.u32cMonth = 6;
	sInitTime.u32cDay = 26;
	sInitTime.u32cHour = 7;
	sInitTime.u32cMinute = 30;
	sInitTime.u32cSecond = 0;
	sInitTime.u32cDayOfWeek = RTC_TUESDAY;
	sInitTime.u8cClockDisplay = RTC_CLOCK_24;
	//sInitTime.u8cAmPm = RTC_AM;

	/* Initialization the RTC timer */
	if(RTC_Open(&sInitTime) !=E_RTC_SUCCESS)
	    sysprintf("Open Fail!!\n");

	 sysprintf("Do RTC Calibration \n");
       RTC_Ioctl(0,RTC_IOC_SET_FREQUENCY, 0,0);	

//////////////////////////////////////////////////////////////////////////////////////
#if 1
        

        /* Set Tick property */
        sTick.ucMode = RTC_TICK_1_SEC;
        sTick.pfnTickCallBack = RTC_TickISR;

        /* Set Tick setting */
        RTC_Ioctl(0,RTC_IOC_SET_TICK_MODE, (UINT32)&sTick,0);

        /* Enable RTC Tick Interrupt and install tick call back function */
        RTC_Ioctl(0,RTC_IOC_ENABLE_INT, (UINT32)RTC_TICK_INT,0);

      //  RTC_EnableClock(TRUE);   
#endif	 

        
				/* Alarm Setting */
					g_sAlarmTime.u32Year = 2018;
					g_sAlarmTime.u32cMonth = 6;
					g_sAlarmTime.u32cDay = 26;
					g_sAlarmTime.u32cHour = 7;
					g_sAlarmTime.u32cMinute = 30;
					g_sAlarmTime.u32cSecond = 5;
					g_sAlarmTime.u32cDayOfWeek = RTC_TUESDAY;
					g_sAlarmTime.u8cClockDisplay = RTC_CLOCK_24;

					/* Set Alarm call back function */
					g_sAlarmTime.pfnAlarmCallBack = RTC_AlarmISR;/*RTC_AlarmISR*/;
#if 1
					/* Enable Alarm Mask for Day */
					g_sAlarmTime.u32AlarmMaskSecond = 0;
					g_sAlarmTime.u32AlarmMaskMinute = 0;
					g_sAlarmTime.u32AlarmMaskHour = 0;
#endif
					/* Set the alarm time (Install the call back function and enable the alarm interrupt)*/
					RTC_Write(RTC_ALARM_TIME,&g_sAlarmTime);
					
					RTC_EnableClock(TRUE);
}

void Alarm_ResetValue(void)
{
    RTC_Read(RTC_CURRENT_TIME, &g_sCurTime);
	  
	  g_sAlarmTime.u32Year = g_sCurTime.u32Year;
		//g_sAlarmTime.u32cMonth = 6;
		g_sAlarmTime.u32cDay = g_sCurTime.u32cDay;
		//g_sAlarmTime.u32cHour = 7;
		//g_sAlarmTime.u32cMinute = 30;
		//g_sAlarmTime.u32cSecond = 5;
		g_sAlarmTime.u32cDayOfWeek = g_sCurTime.u32cDayOfWeek;
		g_sAlarmTime.u8cClockDisplay = g_sCurTime.u8cClockDisplay;
	
	  g_sAlarmTime.pfnAlarmCallBack = RTC_AlarmISR;
	
//	  RTC_Write(RTC_ALARM_TIME,&g_sAlarmTime);
}

WM_HWIN CreateFramewin(void);

int main(void)
{
#ifdef __USE_SD__
    FRESULT     res;
#else
    uint16_t u16ID;
#endif
	  outpw(REG_CLK_HCLKEN, 0x0527);
	  outpw(REG_CLK_PCLKEN0, 0);
	  outpw(REG_CLK_PCLKEN1, 0);

    *((volatile unsigned int *)REG_AIC_MDCR)=0xFFFFFFFF;  // disable all interrupt channel
    *((volatile unsigned int *)REG_AIC_MDCRH)=0xFFFFFFFF;  // disable all interrupt channel
    *(volatile unsigned int *)(CLK_BA+0x18) |= (1<<16); /* Enable UART0 */
    *(volatile unsigned int *)(CLK_BA+0x18) |= (1<<3); /* Enable GPIO */
    sysDisableCache();
    sysFlushCache(I_D_CACHE);	
    sysEnableCache(CACHE_WRITE_BACK);
    sysInitializeUART();
    RTC_Alarm_init();
#ifdef GUI_SUPPORT_TOUCH
    g_enable_Touch = 0;
#endif

		 /* Set MFP_GPJ0 ~ GPJ4 to GPIO */
	  outpw(REG_SYS_GPJ_MFPL, (inpw(REG_SYS_GPJ_MFPL) & 0xfff00000) | (0));
	
		 /* Configure PJ0 ~ PJ4 to output mode */
    GPIO_OpenBit(GPIOJ, BIT0, DIR_OUTPUT, NO_PULL_UP);
	  GPIO_OpenBit(GPIOJ, BIT1, DIR_OUTPUT, NO_PULL_UP);
	  GPIO_OpenBit(GPIOJ, BIT2, DIR_OUTPUT, NO_PULL_UP);
	  GPIO_OpenBit(GPIOJ, BIT3, DIR_OUTPUT, NO_PULL_UP);
	  GPIO_OpenBit(GPIOJ, BIT4, DIR_OUTPUT, NO_PULL_UP);
    OS_TimeMS = 0;

    SYS_Init();

    sysSetTimerReferenceClock(TIMER0, 12000000);
    sysStartTimer(TIMER0, 1000, PERIODIC_MODE);         /* 1000 ticks/per sec ==> 1tick/1ms */
    sysSetTimerEvent(TIMER0,  1, (PVOID)TMR0_IRQHandler);           /*  1 tick  per call back */
    sysSetTimerEvent(TIMER0, 10, (PVOID)TMR0_IRQHandler_TouchTask); /* 10 ticks per call back */

#ifdef __USE_SD__
    sysInstallISR(HIGH_LEVEL_SENSITIVE|IRQ_LEVEL_1, SDH_IRQn, (PVOID)SDH_IRQHandler);
    sysEnableInterrupt(SDH_IRQn);
#endif

    sysSetLocalInterrupt(ENABLE_IRQ);

    sysprintf("+-------------------------------------------------+\n");
    sysprintf("|                 Tslib Sample Code               |\n");
    sysprintf("+-------------------------------------------------+\n\n");
    LCD_initial();

#ifdef GUI_SUPPORT_TOUCH
    Init_TouchPanel();

#ifdef __USE_SD__
    SD_SetReferenceClock(300000);
    SD_Open_Disk(SD_PORT0 | CardDetect_From_GPIO);
    if (gCardInit)
    {
        gCardInit = 0;
        SD_Open_Disk(SD_PORT0 | CardDetect_From_GPIO);
    }

    if(!(SD_CardDetection(SD_Drv)))
        while(1);
    sysprintf("rc=%d\n", (WORD)disk_initialize(0));
    disk_read(0, Buff, 2, 1);
    f_mount(&FatFs[0], "", 0);  // for FATFS v0.11
#endif

 //   GUI_Init();

#ifdef __USE_SD__
    res = f_open(&hFile, "0:\\ts_calib", FA_OPEN_EXISTING | FA_READ);
    if (res)
    {
        // file does not exists, so do calibration
        res = f_open(&hFile, "0:\\ts_calib", FA_CREATE_ALWAYS | FA_WRITE);
        if ( res )
        {
            f_close(&hFile);
            GUI_DispStringAt("CANNOT create the calibration file.\nPlease insert a SD card then reboot.", 0, 0);
            while(1);
        }

        ts_calibrate(__DEMO_TS_WIDTH__, __DEMO_TS_HEIGHT__);
        //GUI_SetDrawMode(GUI_DRAWMODE_NORMAL);
        ts_writefile();
    }
    else
    {
        ts_readfile();
    }
    f_close(&hFile);
#else
    _DemoSpiInit();

    // check flash id
    if((u16ID = SpiFlash_ReadMidDid()) == 0xEF17)
        sysprintf("Flash found: W25Q128BV ...\n");
    else
        sysprintf("Flash ID, 0x%x\n", u16ID);

    SpiFlash_NormalRead(__DEMO_TSFILE_ADDR__, DestArray, 32);
    g_pu32Res = (uint32_t *)DestArray;
    sysprintf("%x\n", g_pu32Res[7]);
    if (g_pu32Res[7] != 0x55AAA55A)
    {
        ts_calibrate(XSIZE_PHYS, YSIZE_PHYS);
        //GUI_SetDrawMode(GUI_DRAWMODE_NORMAL);
        sysprintf("Sector Erase ...");

        /* Sector erase SPI flash */
        SpiFlash_SectorErase(__DEMO_TSFILE_ADDR__);

        /* Wait ready */
        SpiFlash_WaitReady();

        ts_writefile();
        sysprintf("[OK]\n");
    }
    else
        ts_readfile();
#endif

//    ts_test(__DEMO_TS_WIDTH__, __DEMO_TS_HEIGHT__);

    g_enable_Touch = 1;
#endif

		
   /*  */
	//AppTaskCreate();
		xTaskCreate( AppTaskStart,     		/*   */
                 "AppTaskStart",   		/*     */
                 512,            		/* ջСλwordҲ4ֽ */
                 NULL,           		/*   */
                 3,              		/* ȼ*/
                 &xHandleTaskStart );   /*   */

	/* ͨŻ */
	AppObjCreate();
	
    /* ȣʼִ */
    vTaskStartScheduler();

	/* 
	  ϵͳǲеģеＫпڶʱ߿
	  heapռ䲻ɴʧܣҪӴFreeRTOSConfig.hļжheapС
	  #define configTOTAL_HEAP_SIZE	      ( ( size_t ) ( 17 * 1024 ) )
	*/
	while(1);

}
void delay(int nCnt)
{
    int volatile loop;
    for (loop=0; loop<nCnt*10; loop++);
}

uint8_t Get_key(void)
{
	  uint8_t key_value = 0, gpio_key;
	  uint8_t a = 0;
	  
//	  while(1)
//	  {
			GPIO_Set(GPIOJ, BIT0);
	    GPIO_Set(GPIOJ, BIT1);
	    GPIO_Set(GPIOJ, BIT2);
	    GPIO_ClrBit(GPIOJ, BIT3);
	    GPIO_ClrBit(GPIOJ, BIT4);
			gpio_key = GPIO_ReadPort(GPIOJ);//0x07
			if(gpio_key != 0x07)
			{
				delay(100);
				gpio_key = GPIO_ReadPort(GPIOJ);
				if(gpio_key != 0x07)
				{
					switch(gpio_key)
					{
						case 0x0f: //Col0
							key_value = 1;
						  break;
						
						case 0x017: //Col1
							key_value = 2;
						  break;
					}
					
					GPIO_ClrBit(GPIOJ, BIT0);
					GPIO_ClrBit(GPIOJ, BIT1);
					GPIO_ClrBit(GPIOJ, BIT2);
					GPIO_Set(GPIOJ, BIT3);
					GPIO_Set(GPIOJ, BIT4);
					gpio_key = GPIO_ReadPort(GPIOJ);//0x18
					switch(gpio_key)
					{
						case 0x19: //Row0
							key_value = key_value;
						  break;
						
						case 0x1a: //Row1
							key_value = key_value + 4;
						  break;
            
            case 0x1c: //Row2
							key_value = key_value + 8;
						  break; 						
					}
					
					while( (a < 50) && (gpio_key != 0x18) )
					{
						delay(500);
						a++;
					}	
				}	
			}	
		//	 sysprintf("key_value = %d \r\n",key_value);
			 return key_value;     
	//	}
}

/*
*********************************************************************************************************
*	  : vTaskGUI
*	˵: emWin
*	    : pvParameters ڴʱݵβ
*	  ֵ: 
*     : 1   (ֵԽСȼԽͣuCOS෴)
*********************************************************************************************************
*/
static void vTaskGUI(void *pvParameters)
{
	while (1) 
	{
		MainTask();
	}
}

/*
*********************************************************************************************************
*	  : vTaskTaskUserIF
*	˵: Ϣ		
*	    : pvParameters ڴʱݵβ
*	  ֵ: 
*     : 2 
*********************************************************************************************************
*/


static void vTaskTaskUserIF(void *pvParameters)
{
	uint8_t ucKeyCode;
	uint8_t pcWriteBuffer[500];
	

    while(1)
    {
		ucKeyCode = Get_key();
		
		if (ucKeyCode != 0)
		{
			switch (ucKeyCode)
			{			
				case 1:			/* K1ʵֶԻĴ  */
					
					break;

				case 2:			/* K2ʵICONVIEWľ۽ */
					
					break;

				case 5:     /* K3ʵICONVIEWѡ */
					GUI_SendKeyMsg(GUI_KEY_UP, 1);
					
				  break;
				
				case 6:     /* K4ʵICONVIEWѡ  */
					GUI_SendKeyMsg(GUI_KEY_DOWN, 1);
					
				  break;
				
				case 9:  /* K5ʵICONVIEWѡ  */
					GUI_SendKeyMsg(GUI_KEY_LEFT, 1);
					
				  break;
				
				case 10:  /* K6ʵICONVIEWѡ  */
					GUI_SendKeyMsg(GUI_KEY_RIGHT, 1);
					
				  break;
				
				default:                    /* ļֵ */
					break;
			}
		}
		
		vTaskDelay(20);
	}
}

/*
*********************************************************************************************************
*	  : AppTaskCreate
*	˵: Ӧ
*	    : 
*	  ֵ: 
*********************************************************************************************************
*/
static void AppTaskCreate (void)
{
	xTaskCreate(  vTaskGUI,             /*   */
                  "vTaskGUI",           /*     */
                  2048,                 /* ջСλwordҲ4ֽ */
                  NULL,                 /*   */
                  1,                    /* ȼ*/
                  NULL );               /*   */
		
    xTaskCreate( vTaskTaskUserIF,   	/*   */
                 "vTaskUserIF",     	/*     */
                 512,               	/* ջСλwordҲ4ֽ */
                 NULL,              	/*   */
                 2,                 	/* ȼ*/
                 &xHandleTaskUserIF );  /*   */
						 
}

/*
*********************************************************************************************************
*	  : AppObjCreate
*	˵: ͨŻ
*	    : 
*	  ֵ: 
*********************************************************************************************************
*/
static void AppObjCreate (void)
{
	/* ź */
    xMutex = xSemaphoreCreateMutex();
	
	if(xMutex == NULL)
    {
        /* ûдɹû봴ʧܵĴ */
    }
}
static void AppTaskStart(void *pvParameters)
{
    AppTaskCreate();                                           
    GUI_Init();
	
	  while (1)
	  {                                         				
		/* Handle ALARM background process */
        ALARM_BackgroundProcess();
		
		    vTaskDelay(10);	
    }
}